==> erp5.recipe.createsite-1.0.tar.gz: erp5.recipe.createsite-1.0/src/erp5/recipe/createsite/__init__.py <==
# -*- coding: utf-8 -*-
##############################################################################
#
# Copyright (c) 2010 Nexedi SA and Contributors. All Rights Reserved.
# Copyright (c) 2006-2008 Zope Corporation and Contributors.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#
##############################################################################

import os, re, shutil, tempfile, urllib2, urlparse
import setuptools.archive_util

class Recipe:
    '''Recipe to create an ERP5 site using zopectl run
    '''

    def __init__(self, buildout, name, options):
        self.buildout, self.name, self.options = buildout, name, options
        if not options.get('control-script'):
            # Guess the name of the zope control script by looking at the section using
            # zope2instance recipe
            for k, v in self.buildout.items():
                if v.get('recipe') in ('plone.recipe.zope2instance',
                                       'erp5.recipe.zope2instance'):
                    instance_script = v.get('control-script')
                    options['control-script'] = instance_script or k
                    options['instance-location'] = v['location']
            assert 'control-script' in options, 'Unable to find a zope2 instance'

        options['bin-directory'] = buildout['buildout']['bin-directory']

    def install(self):
        options = self.options
        zeo_ctl = options.get('zeo-control-script', None)
        if zeo_ctl:
          zeo_ctl_path = os.path.join(options['bin-directory'], zeo_ctl)
          assert os.spawnl(
              os.P_WAIT, zeo_ctl_path, *[zeo_ctl_path, 'start']) == 0
        zopectl_path = os.path.join(options['bin-directory'],
                                    options['control-script'])
        script_name = os.path.join(os.path.dirname(__file__),
                                  'create_erp5_instance.py')
        argv = [zopectl_path, 'run', script_name]

        if options.get('portal_id'):
            argv.extend(['--portal_id', options['portal_id']])
        if options.get('erp5_sql_connection_string'):
            argv.extend(['--erp5_sql_connection_string',
                        options['erp5_sql_connection_string']])

        if options.get('cmf_activity_sql_connection_string'):
            argv.extend(['--cmf_activity_sql_connection_string',
                 options['cmf_activity_sql_connection_string']])
        if options.get('erp5_catalog_storage'):
            argv.extend(['--erp5_catalog_storage',
                        options['erp5_catalog_storage']])
        if options.get('user'):
            # XXX read rom zope2instance section ?
            argv.extend(['--initial-user',
                        options['user']])

        argv.extend(['--bt5-path',
                    os.path.join(options['bt5-path'])])
        argv.extend([bt for bt in options.get('bt5', '').split('\n') if bt])

        assert os.spawnl(
              os.P_WAIT, zopectl_path, *argv ) == 0
        
        return []

    def update(self):
        pass

==> erp5.recipe.createsite-1.0.1.tar.gz: erp5.recipe.createsite-1.0.1/src/erp5/recipe/createsite/__init__.py <==
# -*- coding: utf-8 -*-
##############################################################################
#
# Copyright (c) 2010 Nexedi SA and Contributors. All Rights Reserved.
# Copyright (c) 2006-2008 Zope Corporation and Contributors.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#
##############################################################################

import os, re, shutil, tempfile, urllib2, urlparse
import setuptools.archive_util

class Recipe:
    '''Recipe to create an ERP5 site using zopectl run
    '''

    def __init__(self, buildout, name, options):
        self.buildout, self.name, self.options = buildout, name, options
        if not options.get('control-script'):
            # Guess the name of the zope control script by looking at the section using
            # zope2instance recipe
            for k, v in self.buildout.items():
                if v.get('recipe') in ('plone.recipe.zope2instance',
                                       'erp5.recipe.zope2instance'):
                    instance_script = v.get('control-script')
                    options['control-script'] = instance_script or k
                    options['instance-location'] = v['location']
            assert 'control-script' in options, 'Unable to find a zope2 instance'

        options['bin-directory'] = buildout['buildout']['bin-directory']

    def install(self):
        options = self.options
        zeo_ctl = options.get('zeo-control-script', None)
        if zeo_ctl:
          zeo_ctl_path = os.path.join(options['bin-directory'], zeo_ctl)
          assert os.spawnl(
              os.P_WAIT, zeo_ctl_path, *[zeo_ctl_path, 'start']) == 0
        zopectl_path = os.path.join(options['bin-directory'],
                                    options['control-script'])
        script_name = os.path.join(os.path.dirname(__file__),
                                  'create_erp5_instance.py')
        argv = [zopectl_path, 'run', script_name]

        if options.get('portal_id'):
            argv.extend(['--portal_id', options['portal_id']])
        if options.get('erp5_sql_connection_string'):
            argv.extend(['--erp5_sql_connection_string',
                        options['erp5_sql_connection_string']])

        if options.get('cmf_activity_sql_connection_string'):
            argv.extend(['--cmf_activity_sql_connection_string',
                 options['cmf_activity_sql_connection_string']])
        if options.get('erp5_catalog_storage'):
            argv.extend(['--erp5_catalog_storage',
                        options['erp5_catalog_storage']])
        if options.get('user'):
            # XXX read rom zope2instance section ?
            argv.extend(['--initial-user',
                        options['user']])

        path_list = []
        for path in options['bt5-path'].split('\n'):
          if path:
            path_list.append(path)
        argv.extend(['--bt5-path', ','.join(path_list)])
        argv.extend([bt for bt in options.get('bt5', '').split('\n') if bt])

        assert os.spawnl(
              os.P_WAIT, zopectl_path, *argv ) == 0
        
        return []

    def update(self):
        pass
